@@ -1,5 +1,5 @@
 import os
-import traceback
+
 import geopandas as gpd
 
 import numpy as np
@@ -9,11 +9,11 @@ from typing import Union, List, Optional, Tuple
 import shapely
 from affine import Affine
 from rasterio import CRS, windows
-from rasterio.enums import Resampling
+
 
 from rasterio.mask import mask
 from rasterio.transform import from_bounds
-from rasterio.warp import calculate_default_transform, reproject
+
 from shapely import box
 
 from digitalarzengine.io.file_io import FileIO
