@@ -1,7 +1,7 @@
 import sys
 import traceback
 
-from digitalarzengine.adapters.db_manager import DBManager
+from digitalarzengine.io.managers.db_manager import DBManager
 from digitalarzengine.scripts.snow_cover import *
 from digitalarzengine.scripts.water.jrc_monthly import JRCMonthlyRecurrence
 
